@@ -17,6 +17,7 @@ from arcane.pubsub import Client as PubSubClient
 from .tracking import send_tracking_information
 
 CLIENTS_KIND = 'base-clients'
+USERS_KIND = 'users'
 
 rights_mapper = {
     '0': "None",
@@ -72,10 +73,9 @@ def check_access_rights(service: str,
                 print("App Engine calls service : " + service)
                 return job_func(*args, **kwargs)
 
-            if not auth_enabled:
-                authorized_clients = [ALL_CLIENTS_RIGHTS]
-            else:
-                claims = {}
+            claims = {}
+            # Check feature rights
+            if auth_enabled:
                 token = str(request.headers.get('Authorization', '')).split(' ').pop()
                 origin = str(request.headers.get('origin', ''))
                 try:
@@ -96,32 +96,34 @@ def check_access_rights(service: str,
                     pass
 
                 rights = claims.get('features_rights', {}).get(service_user_right, RightsLevelEnum.NONE)
-                authorized_clients = claims.get(CLIENTS_PARAM, [])
                 if rights < required_rights:
                     return {'detail': f"You don't have access to this resource : your rights are "
                             f"'{rights_mapper.get(str(rights), '0')}' for service '{service}'. "
                             f"You need '{rights_mapper.get(str(required_rights), '0')}'.",
                             'claims': f"Your current rights are {json.dumps(claims, indent=4, sort_keys=True)}"}, 401
 
+            # Fill authorized_clients
             if receive_rights_per_client:
-                if CLIENTS_PARAM in kwargs:
-                    warnings.warn(f'field {CLIENTS_PARAM} when calling {job_func.__name__} was already filled.\n'
-                                  f'Crushing existing value {str(kwargs[CLIENTS_PARAM])}')
+                if not auth_enabled:
+                    authorized_clients = [ALL_CLIENTS_RIGHTS]
+                else:
+                    db_user_id = claims.get('db_user_id')
+                    if not db_user_id:
+                        authorized_clients = []
+                    else:
+                        user = datastore_client.get_entity(USERS_KIND, int(db_user_id))
+                        if user is None:
+                            authorized_clients = []
+                        else:
+                            authorized_clients = user.get('authorized_clients', [])
+
                 if ALL_CLIENTS_RIGHTS in authorized_clients:
                     authorized_clients.remove(ALL_CLIENTS_RIGHTS)
                     clients_query = datastore_client.query()
                     clients_query.kind = CLIENTS_KIND
                     clients_query.keys_only()
-                    authorized_clients.extend(
-                        [client_entity.key.name for client_entity in clients_query.fetch()
-                         if client_entity.key.name not in authorized_clients])
-                else:
-                    clients_query = datastore_client.query()
-                    clients_query.kind = CLIENTS_KIND
-                    clients_query.projection = ['name', 'right_id']
-                    new_authorized_clients = [client_entity['name'] for client_entity in clients_query.fetch()
-                                            if client_entity['right_id'] in authorized_clients]
-                    authorized_clients = new_authorized_clients
+                    authorized_clients = [client_entity.key.name for client_entity in clients_query.fetch()]
+
                 kwargs[CLIENTS_PARAM] = sorted(set(authorized_clients))
 
             return job_func(*args, **kwargs)
